@@ -340,10 +340,10 @@ when editing big diffs)."
 
 ;; XEmacs change: we don't have combine-after-change-calls.
 (eval-when-compile
-  (unless (boundp 'combine-after-change-calls)
+  (unless (fboundp 'combine-after-change-calls)
     (defmacro combine-after-change-calls (&rest body)
       "Execute `body'."
-      `(progn . ,body))))
+      `(progn ,@body))))
 
 ;;;;
 ;;;; Compile support
@@ -1313,8 +1313,7 @@ For use in `add-log-current-defun-function'."
 	    (add-log-current-defun))))))
 
 ;; XEmacs change: added.
-;;;###autoload
-(add-to-list 'auto-mode-alist '("\\.\\(diffs?\\|patch\\|rej\\)\\'" . diff-mode))
+;;;###autoload(add-to-list 'auto-mode-alist '("\\.\\(diffs?\\|patch\\|rej\\)\\'" . diff-mode))
 
 ;; provide the package
 (provide 'diff-mode)
